Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Panorama.

Actions, resources, and condition keys for AWS Panorama - Service Authorization Reference

# Actions, resources, and condition keys for AWS Panorama

AWS Panorama (service prefix: `panorama` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Panorama
- Resource types defined by AWS Panorama
- Condition keys for AWS Panorama

## Actions defined by AWS Panorama

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateApp [permission only] | Grants permission to create an AWS Panorama application | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateAppDeployment [permission only] | Grants permission to deploy an AWS Panorama application | Write |  |  |
CreateAppVersion [permission only] | Grants permission to create a version of an AWS Panorama application | Write | appVersion* |  |
CreateApplicationInstance | Grants permission to create an AWS Panorama Application Instance | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateDataSource [permission only] | Grants permission to create an AWS Panorama datasource | Write | device* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateDeploymentConfiguration [permission only] | Grants permission to configure a deployment for an AWS Panorama application | Write |  |  |
CreateInputs [permission only] | Grants permission to generate a list of cameras on the same network as an AWS Panorama Appliance | Write | device* |  |
CreateJobForDevices [permission only] | Grants permission to create a job for an AWS Panorama Appliance | Write |  |  |
CreateModel [permission only] | Grants permission to import a machine learning model into AWS Panorama | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateNodeFromTemplateJob | Grants permission to create an AWS Panorama Node | Write |  |  |
CreatePackage | Grants permission to create an AWS Panorama Package | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreatePackageImportJob | Grants permission to create an AWS Panorama Package | Write |  |  |
CreateStreams [permission only] | Grants permission to generate a list of streams available to an AWS Panorama Appliance | Write | device* |  |
DeleteApp [permission only] | Grants permission to delete an AWS Panorama application | Write | app* |  |
DeleteAppVersion [permission only] | Grants permission to delete a version of an AWS Panorama application | Write | app* |  |
DeleteDataSource [permission only] | Grants permission to delete an AWS Panorama datasource | Write | dataSource* |  |
DeleteDevice [permission only] | Grants permission to deregister an AWS Panorama Appliance | Write | device* |  |
DeleteModel [permission only] | Grants permission to delete a machine learning model from AWS Panorama | Write | model* |  |
DeletePackage | Grants permission to delete an AWS Panorama Package | Write | package* |  |
DeregisterPackageVersion | Grants permission to deregister an AWS Panorama Package Version | Write |  |  |
DescribeApp [permission only] | Grants permission to view details about an AWS Panorama application | Read | app* |  |
DescribeAppDeployment [permission only] | Grants permission to view details about a deployment for an AWS Panorama application | Read |  |  |
DescribeAppVersion [permission only] | Grants permission to view details about a version of an AWS Panorama application | Read | app* |  |
DescribeApplicationInstance | Grants permission to view details about an AWS Panorama Application Instance | Read | applicationInstance* |  |
DescribeApplicationInstanceDetails | Grants permission to view details about an AWS Panorama Application Instance | Read | applicationInstance* |  |
DescribeDataSource [permission only] | Grants permission to view details about a datasource in AWS Panorama | Read | dataSource* |  |
DescribeDevice [permission only] | Grants permission to view details about an AWS Panorama Appliance | Read | device* |  |
DescribeDeviceJob [permission only] | Grants permission to view job details for an AWS Panorama Appliance | Read |  |  |
DescribeModel [permission only] | Grants permission to view details about a machine learning model in AWS Panorama | Read | model* |  |
DescribeNode | Grants permission to view details about an AWS Panorama Node | Read |  |  |
DescribeNodeFromTemplateJob | Grants permission to view details about AWS Panorama Node | Read |  |  |
DescribePackage | Grants permission to view details about an AWS Panorama Package | Read | package* |  |
DescribePackageImportJob | Grants permission to view details about an AWS Panorama Package | Read |  |  |
DescribePackageVersion | Grants permission to view details about an AWS Panorama Package Version | Read |  |  |
DescribeSoftware [permission only] | Grants permission to view details about a software version for the AWS Panorama Appliance | Read |  |  |
GetDeploymentConfiguration [permission only] | Grants permission to view details about a deployment configuration for an AWS Panorama application | Read |  |  |
GetInputs [permission only] | Grants permission to retrieve a list of cameras generated with CreateInputs | Read | device* |  |
GetStreams [permission only] | Grants permission to retrieve a list of streams generated with CreateStreams | Read | device* |  |
GetWebSocketURL [permission only] | Grants permission to generate a WebSocket endpoint for communication with AWS Panorama | Read |  |  |
ListAppDeploymentOperations [permission only] | Grants permission to retrieve a list of deployments for an AWS Panorama application | List |  |  |
ListAppVersions [permission only] | Grants permission to retrieve a list of application versions in AWS Panorama | List | app* |  |
ListApplicationInstanceDependencies | Grants permission to retrieve a list of application instance dependencies in AWS Panorama | List |  |  |
ListApplicationInstanceNodeInstances | Grants permission to retrieve a list of node instances of application instances in AWS Panorama | List |  |  |
ListApplicationInstances | Grants permission to retrieve a list of application instances in AWS Panorama | List |  |  |
ListApps [permission only] | Grants permission to retrieve a list of applications in AWS Panorama | List |  |  |
ListDataSources [permission only] | Grants permission to retrieve a list of datasources in AWS Panorama | List | device* |  |
ListDeploymentConfigurations [permission only] | Grants permission to retrieve a list of deployment configurations in AWS Panorama | List |  |  |
ListDevices [permission only] | Grants permission to retrieve a list of appliances in AWS Panorama | List |  |  |
ListDevicesJobs [permission only] | Grants permission to retrieve a list of jobs for an AWS Panorama Appliance | List |  |  |
ListModels [permission only] | Grants permission to retrieve a list of models in AWS Panorama | List |  |  |
ListNodeFromTemplateJobs | Grants permission to retrieve a list of Nodes for an AWS Panorama Appliance | List |  |  |
ListNodes | Grants permission to retrieve a list of nodes in AWS Panorama | List |  |  |
ListPackageImportJobs | Grants permission to retrieve a list of packages in AWS Panorama | List |  |  |
ListPackages | Grants permission to retrieve a list of packages in AWS Panorama | List |  |  |
ListTagsForResource [permission only] | Grants permission to retrieve a list of tags for a resource in AWS Panorama | Read | app |  |
dataSource |  |
device |  |
model |  |
ProvisionDevice [permission only] | Grants permission to register an AWS Panorama Appliance | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
RegisterPackageVersion | Grants permission to register an AWS Panorama Package Version | Write |  |  |
RemoveApplicationInstance | Grants permission to remove an AWS Panorama Application Instance | Write | applicationInstance* |  |
TagResource [permission only] | Grants permission to add tags to a resource in AWS Panorama | Tagging | app |  |
dataSource |  |
device |  |
model |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource [permission only] | Grants permission to remove tags from a resource in AWS Panorama | Tagging | app |  |
dataSource |  |
device |  |
model |  |
| aws:TagKeys |
UpdateApp [permission only] | Grants permission to modify an AWS Panorama application | Write | app* |  |
UpdateAppConfiguration [permission only] | Grants permission to modify the version-specific configuration of an AWS Panorama application | Write | app* |  |
UpdateDataSource [permission only] | Grants permission to modify an AWS Panorama datasource | Write | dataSource* |  |
UpdateDeviceMetadata [permission only] | Grants permission to modify basic settings for an AWS Panorama Appliance | Write |  |  |

## Resource types defined by AWS Panorama

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
device | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:device/$ { DeviceId}` | aws:ResourceTag/${TagKey}
package | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:package/$ { PackageId}` | aws:ResourceTag/${TagKey}
applicationInstance | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:applicationInstance/$ { ApplicationInstanceId}` | aws:ResourceTag/${TagKey}
dataSource | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:dataSource/$ { DeviceId}/$ { DataSourceName}` | aws:ResourceTag/${TagKey}
model | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:model/$ { ModelName}` | aws:ResourceTag/${TagKey}
app | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:app/$ { AppName}` | aws:ResourceTag/${TagKey}
appVersion | `arn:$ { Partition}:panorama:$ { Region}:$ { Account}:app/$ { AppName}:$ { AppVersion}` |

## Condition keys for AWS Panorama

AWS Panorama defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.